@@ -782,3 +782,11 @@ class VariableClHelpSet(ReadonlyVariable):
     """
     type = "bool"
     value = "off"
+
+
+class VariableClConsoleArgs(Variable):
+    """
+    Список аргументов переданных через консоль
+    """
+    type = "list"
+    value = []
